#HELLO AND WELCOME TO THE READ.ME

This package lets you create cut ups with text in the style of William Burroughs. There are a couple of ways of doing this

1 Cutting a page into 4 sections by sentence
2 Cutting a page into 4 sections by line
3 Creating a fold from two texts